# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ByoipRange(object):
    """
    Oracle offers the ability to Bring Your Own IP (BYOIP), importing public IP addresses or IPv6 addresses that you currently own to Oracle Cloud Infrastructure. A `ByoipRange` resource is a record of the imported address block (a BYOIP CIDR block) and also some associated metadata.
    The process used to `Bring Your Own IP`__ is explained in the documentation.

    __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/BYOIP.htm
    """

    #: A constant which can be used with the lifecycle_details property of a ByoipRange.
    #: This constant has a value of "CREATING"
    LIFECYCLE_DETAILS_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_details property of a ByoipRange.
    #: This constant has a value of "VALIDATING"
    LIFECYCLE_DETAILS_VALIDATING = "VALIDATING"

    #: A constant which can be used with the lifecycle_details property of a ByoipRange.
    #: This constant has a value of "PROVISIONED"
    LIFECYCLE_DETAILS_PROVISIONED = "PROVISIONED"

    #: A constant which can be used with the lifecycle_details property of a ByoipRange.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_DETAILS_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_details property of a ByoipRange.
    #: This constant has a value of "FAILED"
    LIFECYCLE_DETAILS_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_details property of a ByoipRange.
    #: This constant has a value of "DELETING"
    LIFECYCLE_DETAILS_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_details property of a ByoipRange.
    #: This constant has a value of "DELETED"
    LIFECYCLE_DETAILS_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_details property of a ByoipRange.
    #: This constant has a value of "ADVERTISING"
    LIFECYCLE_DETAILS_ADVERTISING = "ADVERTISING"

    #: A constant which can be used with the lifecycle_details property of a ByoipRange.
    #: This constant has a value of "WITHDRAWING"
    LIFECYCLE_DETAILS_WITHDRAWING = "WITHDRAWING"

    #: A constant which can be used with the lifecycle_state property of a ByoipRange.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a ByoipRange.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a ByoipRange.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a ByoipRange.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a ByoipRange.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    def __init__(self, **kwargs):
        """
        Initializes a new ByoipRange object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param byoip_range_vcn_ipv6_allocations:
            The value to assign to the byoip_range_vcn_ipv6_allocations property of this ByoipRange.
        :type byoip_range_vcn_ipv6_allocations: list[oci.core.models.ByoipRangeVcnIpv6AllocationSummary]

        :param cidr_block:
            The value to assign to the cidr_block property of this ByoipRange.
        :type cidr_block: str

        :param compartment_id:
            The value to assign to the compartment_id property of this ByoipRange.
        :type compartment_id: str

        :param defined_tags:
            The value to assign to the defined_tags property of this ByoipRange.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this ByoipRange.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this ByoipRange.
        :type freeform_tags: dict(str, str)

        :param id:
            The value to assign to the id property of this ByoipRange.
        :type id: str

        :param ipv6_cidr_block:
            The value to assign to the ipv6_cidr_block property of this ByoipRange.
        :type ipv6_cidr_block: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this ByoipRange.
            Allowed values for this property are: "CREATING", "VALIDATING", "PROVISIONED", "ACTIVE", "FAILED", "DELETING", "DELETED", "ADVERTISING", "WITHDRAWING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_details: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this ByoipRange.
            Allowed values for this property are: "INACTIVE", "UPDATING", "ACTIVE", "DELETING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this ByoipRange.
        :type time_created: datetime

        :param time_validated:
            The value to assign to the time_validated property of this ByoipRange.
        :type time_validated: datetime

        :param time_advertised:
            The value to assign to the time_advertised property of this ByoipRange.
        :type time_advertised: datetime

        :param time_withdrawn:
            The value to assign to the time_withdrawn property of this ByoipRange.
        :type time_withdrawn: datetime

        :param validation_token:
            The value to assign to the validation_token property of this ByoipRange.
        :type validation_token: str

        """
        self.swagger_types = {
            'byoip_range_vcn_ipv6_allocations': 'list[ByoipRangeVcnIpv6AllocationSummary]',
            'cidr_block': 'str',
            'compartment_id': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'id': 'str',
            'ipv6_cidr_block': 'str',
            'lifecycle_details': 'str',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'time_validated': 'datetime',
            'time_advertised': 'datetime',
            'time_withdrawn': 'datetime',
            'validation_token': 'str'
        }

        self.attribute_map = {
            'byoip_range_vcn_ipv6_allocations': 'byoipRangeVcnIpv6Allocations',
            'cidr_block': 'cidrBlock',
            'compartment_id': 'compartmentId',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'id': 'id',
            'ipv6_cidr_block': 'ipv6CidrBlock',
            'lifecycle_details': 'lifecycleDetails',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'time_validated': 'timeValidated',
            'time_advertised': 'timeAdvertised',
            'time_withdrawn': 'timeWithdrawn',
            'validation_token': 'validationToken'
        }

        self._byoip_range_vcn_ipv6_allocations = None
        self._cidr_block = None
        self._compartment_id = None
        self._defined_tags = None
        self._display_name = None
        self._freeform_tags = None
        self._id = None
        self._ipv6_cidr_block = None
        self._lifecycle_details = None
        self._lifecycle_state = None
        self._time_created = None
        self._time_validated = None
        self._time_advertised = None
        self._time_withdrawn = None
        self._validation_token = None

    @property
    def byoip_range_vcn_ipv6_allocations(self):
        """
        Gets the byoip_range_vcn_ipv6_allocations of this ByoipRange.
        A list of `ByoipRangeVcnIpv6AllocationSummary` objects.


        :return: The byoip_range_vcn_ipv6_allocations of this ByoipRange.
        :rtype: list[oci.core.models.ByoipRangeVcnIpv6AllocationSummary]
        """
        return self._byoip_range_vcn_ipv6_allocations

    @byoip_range_vcn_ipv6_allocations.setter
    def byoip_range_vcn_ipv6_allocations(self, byoip_range_vcn_ipv6_allocations):
        """
        Sets the byoip_range_vcn_ipv6_allocations of this ByoipRange.
        A list of `ByoipRangeVcnIpv6AllocationSummary` objects.


        :param byoip_range_vcn_ipv6_allocations: The byoip_range_vcn_ipv6_allocations of this ByoipRange.
        :type: list[oci.core.models.ByoipRangeVcnIpv6AllocationSummary]
        """
        self._byoip_range_vcn_ipv6_allocations = byoip_range_vcn_ipv6_allocations

    @property
    def cidr_block(self):
        """
        Gets the cidr_block of this ByoipRange.
        The public IPv4 CIDR block being imported from on-premises to the Oracle cloud.


        :return: The cidr_block of this ByoipRange.
        :rtype: str
        """
        return self._cidr_block

    @cidr_block.setter
    def cidr_block(self, cidr_block):
        """
        Sets the cidr_block of this ByoipRange.
        The public IPv4 CIDR block being imported from on-premises to the Oracle cloud.


        :param cidr_block: The cidr_block of this ByoipRange.
        :type: str
        """
        self._cidr_block = cidr_block

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this ByoipRange.
        The `OCID`__ of the compartment containing the BYOIP CIDR block.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this ByoipRange.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ByoipRange.
        The `OCID`__ of the compartment containing the BYOIP CIDR block.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this ByoipRange.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this ByoipRange.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this ByoipRange.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this ByoipRange.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this ByoipRange.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        Gets the display_name of this ByoipRange.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this ByoipRange.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ByoipRange.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this ByoipRange.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this ByoipRange.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this ByoipRange.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this ByoipRange.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this ByoipRange.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ByoipRange.
        The `OCID`__ of the `ByoipRange` resource.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this ByoipRange.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ByoipRange.
        The `OCID`__ of the `ByoipRange` resource.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this ByoipRange.
        :type: str
        """
        self._id = id

    @property
    def ipv6_cidr_block(self):
        """
        Gets the ipv6_cidr_block of this ByoipRange.
        The IPv6 CIDR block being imported to the Oracle cloud. This CIDR block must be /48 or larger, and can be subdivided into sub-ranges used
        across multiple VCNs. A BYOIPv6 prefix can be also assigned across multiple VCNs, and each VCN must be /64 or larger. You may specify
        a ULA or private IPv6 prefix of /64 or larger to use in the VCN. IPv6-enabled subnets will remain a fixed /64 in size.


        :return: The ipv6_cidr_block of this ByoipRange.
        :rtype: str
        """
        return self._ipv6_cidr_block

    @ipv6_cidr_block.setter
    def ipv6_cidr_block(self, ipv6_cidr_block):
        """
        Sets the ipv6_cidr_block of this ByoipRange.
        The IPv6 CIDR block being imported to the Oracle cloud. This CIDR block must be /48 or larger, and can be subdivided into sub-ranges used
        across multiple VCNs. A BYOIPv6 prefix can be also assigned across multiple VCNs, and each VCN must be /64 or larger. You may specify
        a ULA or private IPv6 prefix of /64 or larger to use in the VCN. IPv6-enabled subnets will remain a fixed /64 in size.


        :param ipv6_cidr_block: The ipv6_cidr_block of this ByoipRange.
        :type: str
        """
        self._ipv6_cidr_block = ipv6_cidr_block

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this ByoipRange.
        The `ByoipRange` resource's current status.

        Allowed values for this property are: "CREATING", "VALIDATING", "PROVISIONED", "ACTIVE", "FAILED", "DELETING", "DELETED", "ADVERTISING", "WITHDRAWING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_details of this ByoipRange.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this ByoipRange.
        The `ByoipRange` resource's current status.


        :param lifecycle_details: The lifecycle_details of this ByoipRange.
        :type: str
        """
        allowed_values = ["CREATING", "VALIDATING", "PROVISIONED", "ACTIVE", "FAILED", "DELETING", "DELETED", "ADVERTISING", "WITHDRAWING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_details, allowed_values):
            lifecycle_details = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_details = lifecycle_details

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this ByoipRange.
        The `ByoipRange` resource's current state.

        Allowed values for this property are: "INACTIVE", "UPDATING", "ACTIVE", "DELETING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this ByoipRange.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this ByoipRange.
        The `ByoipRange` resource's current state.


        :param lifecycle_state: The lifecycle_state of this ByoipRange.
        :type: str
        """
        allowed_values = ["INACTIVE", "UPDATING", "ACTIVE", "DELETING", "DELETED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this ByoipRange.
        The date and time the `ByoipRange` resource was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this ByoipRange.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ByoipRange.
        The date and time the `ByoipRange` resource was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this ByoipRange.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_validated(self):
        """
        Gets the time_validated of this ByoipRange.
        The date and time the `ByoipRange` resource was validated, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_validated of this ByoipRange.
        :rtype: datetime
        """
        return self._time_validated

    @time_validated.setter
    def time_validated(self, time_validated):
        """
        Sets the time_validated of this ByoipRange.
        The date and time the `ByoipRange` resource was validated, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_validated: The time_validated of this ByoipRange.
        :type: datetime
        """
        self._time_validated = time_validated

    @property
    def time_advertised(self):
        """
        Gets the time_advertised of this ByoipRange.
        The date and time the `ByoipRange` resource was advertised to the internet by BGP, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_advertised of this ByoipRange.
        :rtype: datetime
        """
        return self._time_advertised

    @time_advertised.setter
    def time_advertised(self, time_advertised):
        """
        Sets the time_advertised of this ByoipRange.
        The date and time the `ByoipRange` resource was advertised to the internet by BGP, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_advertised: The time_advertised of this ByoipRange.
        :type: datetime
        """
        self._time_advertised = time_advertised

    @property
    def time_withdrawn(self):
        """
        Gets the time_withdrawn of this ByoipRange.
        The date and time the `ByoipRange` resource was withdrawn from advertisement by BGP to the internet, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_withdrawn of this ByoipRange.
        :rtype: datetime
        """
        return self._time_withdrawn

    @time_withdrawn.setter
    def time_withdrawn(self, time_withdrawn):
        """
        Sets the time_withdrawn of this ByoipRange.
        The date and time the `ByoipRange` resource was withdrawn from advertisement by BGP to the internet, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_withdrawn: The time_withdrawn of this ByoipRange.
        :type: datetime
        """
        self._time_withdrawn = time_withdrawn

    @property
    def validation_token(self):
        """
        **[Required]** Gets the validation_token of this ByoipRange.
        The validation token is an internally-generated ASCII string used in the validation process. See `Importing a CIDR block`__ for details.

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/BYOIP.htm#import_cidr


        :return: The validation_token of this ByoipRange.
        :rtype: str
        """
        return self._validation_token

    @validation_token.setter
    def validation_token(self, validation_token):
        """
        Sets the validation_token of this ByoipRange.
        The validation token is an internally-generated ASCII string used in the validation process. See `Importing a CIDR block`__ for details.

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/BYOIP.htm#import_cidr


        :param validation_token: The validation_token of this ByoipRange.
        :type: str
        """
        self._validation_token = validation_token

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .data_source_details import DataSourceDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DataSourceDetailsObjectStorage(DataSourceDetails):
    """
    Data Source details for object storage
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DataSourceDetailsObjectStorage object with values from keyword arguments. The default value of the :py:attr:`~oci.ai_anomaly_detection.models.DataSourceDetailsObjectStorage.data_source_type` attribute
        of this class is ``ORACLE_OBJECT_STORAGE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param data_source_type:
            The value to assign to the data_source_type property of this DataSourceDetailsObjectStorage.
            Allowed values for this property are: "ORACLE_OBJECT_STORAGE", "ORACLE_ATP", "INFLUX"
        :type data_source_type: str

        :param namespace:
            The value to assign to the namespace property of this DataSourceDetailsObjectStorage.
        :type namespace: str

        :param bucket_name:
            The value to assign to the bucket_name property of this DataSourceDetailsObjectStorage.
        :type bucket_name: str

        :param object_name:
            The value to assign to the object_name property of this DataSourceDetailsObjectStorage.
        :type object_name: str

        """
        self.swagger_types = {
            'data_source_type': 'str',
            'namespace': 'str',
            'bucket_name': 'str',
            'object_name': 'str'
        }

        self.attribute_map = {
            'data_source_type': 'dataSourceType',
            'namespace': 'namespace',
            'bucket_name': 'bucketName',
            'object_name': 'objectName'
        }

        self._data_source_type = None
        self._namespace = None
        self._bucket_name = None
        self._object_name = None
        self._data_source_type = 'ORACLE_OBJECT_STORAGE'

    @property
    def namespace(self):
        """
        Gets the namespace of this DataSourceDetailsObjectStorage.
        Object storage namespace


        :return: The namespace of this DataSourceDetailsObjectStorage.
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """
        Sets the namespace of this DataSourceDetailsObjectStorage.
        Object storage namespace


        :param namespace: The namespace of this DataSourceDetailsObjectStorage.
        :type: str
        """
        self._namespace = namespace

    @property
    def bucket_name(self):
        """
        Gets the bucket_name of this DataSourceDetailsObjectStorage.
        Object storage bucket name


        :return: The bucket_name of this DataSourceDetailsObjectStorage.
        :rtype: str
        """
        return self._bucket_name

    @bucket_name.setter
    def bucket_name(self, bucket_name):
        """
        Sets the bucket_name of this DataSourceDetailsObjectStorage.
        Object storage bucket name


        :param bucket_name: The bucket_name of this DataSourceDetailsObjectStorage.
        :type: str
        """
        self._bucket_name = bucket_name

    @property
    def object_name(self):
        """
        Gets the object_name of this DataSourceDetailsObjectStorage.
        File name


        :return: The object_name of this DataSourceDetailsObjectStorage.
        :rtype: str
        """
        return self._object_name

    @object_name.setter
    def object_name(self, object_name):
        """
        Sets the object_name of this DataSourceDetailsObjectStorage.
        File name


        :param object_name: The object_name of this DataSourceDetailsObjectStorage.
        :type: str
        """
        self._object_name = object_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class OrganizationTenancySummary(object):
    """
    An organization tenancy summary entity.
    """

    #: A constant which can be used with the lifecycle_state property of a OrganizationTenancySummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a OrganizationTenancySummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a OrganizationTenancySummary.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a OrganizationTenancySummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a OrganizationTenancySummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a OrganizationTenancySummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the role property of a OrganizationTenancySummary.
    #: This constant has a value of "PARENT"
    ROLE_PARENT = "PARENT"

    #: A constant which can be used with the role property of a OrganizationTenancySummary.
    #: This constant has a value of "CHILD"
    ROLE_CHILD = "CHILD"

    #: A constant which can be used with the role property of a OrganizationTenancySummary.
    #: This constant has a value of "NONE"
    ROLE_NONE = "NONE"

    def __init__(self, **kwargs):
        """
        Initializes a new OrganizationTenancySummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param tenancy_id:
            The value to assign to the tenancy_id property of this OrganizationTenancySummary.
        :type tenancy_id: str

        :param name:
            The value to assign to the name property of this OrganizationTenancySummary.
        :type name: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this OrganizationTenancySummary.
            Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "DELETED", "FAILED", "DELETING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param role:
            The value to assign to the role property of this OrganizationTenancySummary.
            Allowed values for this property are: "PARENT", "CHILD", "NONE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type role: str

        :param time_joined:
            The value to assign to the time_joined property of this OrganizationTenancySummary.
        :type time_joined: datetime

        :param time_left:
            The value to assign to the time_left property of this OrganizationTenancySummary.
        :type time_left: datetime

        :param is_approved_for_transfer:
            The value to assign to the is_approved_for_transfer property of this OrganizationTenancySummary.
        :type is_approved_for_transfer: bool

        """
        self.swagger_types = {
            'tenancy_id': 'str',
            'name': 'str',
            'lifecycle_state': 'str',
            'role': 'str',
            'time_joined': 'datetime',
            'time_left': 'datetime',
            'is_approved_for_transfer': 'bool'
        }

        self.attribute_map = {
            'tenancy_id': 'tenancyId',
            'name': 'name',
            'lifecycle_state': 'lifecycleState',
            'role': 'role',
            'time_joined': 'timeJoined',
            'time_left': 'timeLeft',
            'is_approved_for_transfer': 'isApprovedForTransfer'
        }

        self._tenancy_id = None
        self._name = None
        self._lifecycle_state = None
        self._role = None
        self._time_joined = None
        self._time_left = None
        self._is_approved_for_transfer = None

    @property
    def tenancy_id(self):
        """
        **[Required]** Gets the tenancy_id of this OrganizationTenancySummary.
        OCID of the tenancy.


        :return: The tenancy_id of this OrganizationTenancySummary.
        :rtype: str
        """
        return self._tenancy_id

    @tenancy_id.setter
    def tenancy_id(self, tenancy_id):
        """
        Sets the tenancy_id of this OrganizationTenancySummary.
        OCID of the tenancy.


        :param tenancy_id: The tenancy_id of this OrganizationTenancySummary.
        :type: str
        """
        self._tenancy_id = tenancy_id

    @property
    def name(self):
        """
        Gets the name of this OrganizationTenancySummary.
        Name of the tenancy.


        :return: The name of this OrganizationTenancySummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this OrganizationTenancySummary.
        Name of the tenancy.


        :param name: The name of this OrganizationTenancySummary.
        :type: str
        """
        self._name = name

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this OrganizationTenancySummary.
        Lifecycle state of the OrganizationTenancy.

        Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "DELETED", "FAILED", "DELETING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this OrganizationTenancySummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this OrganizationTenancySummary.
        Lifecycle state of the OrganizationTenancy.


        :param lifecycle_state: The lifecycle_state of this OrganizationTenancySummary.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "INACTIVE", "DELETED", "FAILED", "DELETING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def role(self):
        """
        Gets the role of this OrganizationTenancySummary.
        Role of the OrganizationTenancy.

        Allowed values for this property are: "PARENT", "CHILD", "NONE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The role of this OrganizationTenancySummary.
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """
        Sets the role of this OrganizationTenancySummary.
        Role of the OrganizationTenancy.


        :param role: The role of this OrganizationTenancySummary.
        :type: str
        """
        allowed_values = ["PARENT", "CHILD", "NONE"]
        if not value_allowed_none_or_none_sentinel(role, allowed_values):
            role = 'UNKNOWN_ENUM_VALUE'
        self._role = role

    @property
    def time_joined(self):
        """
        Gets the time_joined of this OrganizationTenancySummary.
        Date-time when this tenancy joined the organization.


        :return: The time_joined of this OrganizationTenancySummary.
        :rtype: datetime
        """
        return self._time_joined

    @time_joined.setter
    def time_joined(self, time_joined):
        """
        Sets the time_joined of this OrganizationTenancySummary.
        Date-time when this tenancy joined the organization.


        :param time_joined: The time_joined of this OrganizationTenancySummary.
        :type: datetime
        """
        self._time_joined = time_joined

    @property
    def time_left(self):
        """
        Gets the time_left of this OrganizationTenancySummary.
        Date-time when this tenancy left the organization.


        :return: The time_left of this OrganizationTenancySummary.
        :rtype: datetime
        """
        return self._time_left

    @time_left.setter
    def time_left(self, time_left):
        """
        Sets the time_left of this OrganizationTenancySummary.
        Date-time when this tenancy left the organization.


        :param time_left: The time_left of this OrganizationTenancySummary.
        :type: datetime
        """
        self._time_left = time_left

    @property
    def is_approved_for_transfer(self):
        """
        Gets the is_approved_for_transfer of this OrganizationTenancySummary.
        Flag to indicate the tenancy is approved for transfer to another organization.


        :return: The is_approved_for_transfer of this OrganizationTenancySummary.
        :rtype: bool
        """
        return self._is_approved_for_transfer

    @is_approved_for_transfer.setter
    def is_approved_for_transfer(self, is_approved_for_transfer):
        """
        Sets the is_approved_for_transfer of this OrganizationTenancySummary.
        Flag to indicate the tenancy is approved for transfer to another organization.


        :param is_approved_for_transfer: The is_approved_for_transfer of this OrganizationTenancySummary.
        :type: bool
        """
        self._is_approved_for_transfer = is_approved_for_transfer

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .typed_object import TypedObject
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class NativeShapeField(TypedObject):
    """
    The native shape field object.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new NativeShapeField object with values from keyword arguments. The default value of the :py:attr:`~oci.data_connectivity.models.NativeShapeField.model_type` attribute
        of this class is ``NATIVE_SHAPE_FIELD`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this NativeShapeField.
            Allowed values for this property are: "SHAPE", "SHAPE_FIELD", "NATIVE_SHAPE_FIELD"
        :type model_type: str

        :param key:
            The value to assign to the key property of this NativeShapeField.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this NativeShapeField.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this NativeShapeField.
        :type parent_ref: oci.data_connectivity.models.ParentReference

        :param config_values:
            The value to assign to the config_values property of this NativeShapeField.
        :type config_values: oci.data_connectivity.models.ConfigValues

        :param object_status:
            The value to assign to the object_status property of this NativeShapeField.
        :type object_status: int

        :param name:
            The value to assign to the name property of this NativeShapeField.
        :type name: str

        :param description:
            The value to assign to the description property of this NativeShapeField.
        :type description: str

        :param type:
            The value to assign to the type property of this NativeShapeField.
        :type type: object

        :param position:
            The value to assign to the position property of this NativeShapeField.
        :type position: int

        :param default_value_string:
            The value to assign to the default_value_string property of this NativeShapeField.
        :type default_value_string: str

        :param is_mandatory:
            The value to assign to the is_mandatory property of this NativeShapeField.
        :type is_mandatory: bool

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'config_values': 'ConfigValues',
            'object_status': 'int',
            'name': 'str',
            'description': 'str',
            'type': 'object',
            'position': 'int',
            'default_value_string': 'str',
            'is_mandatory': 'bool'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'config_values': 'configValues',
            'object_status': 'objectStatus',
            'name': 'name',
            'description': 'description',
            'type': 'type',
            'position': 'position',
            'default_value_string': 'defaultValueString',
            'is_mandatory': 'isMandatory'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._config_values = None
        self._object_status = None
        self._name = None
        self._description = None
        self._type = None
        self._position = None
        self._default_value_string = None
        self._is_mandatory = None
        self._model_type = 'NATIVE_SHAPE_FIELD'

    @property
    def type(self):
        """
        **[Required]** Gets the type of this NativeShapeField.
        The type reference.


        :return: The type of this NativeShapeField.
        :rtype: object
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this NativeShapeField.
        The type reference.


        :param type: The type of this NativeShapeField.
        :type: object
        """
        self._type = type

    @property
    def position(self):
        """
        Gets the position of this NativeShapeField.
        The position of the attribute.


        :return: The position of this NativeShapeField.
        :rtype: int
        """
        return self._position

    @position.setter
    def position(self, position):
        """
        Sets the position of this NativeShapeField.
        The position of the attribute.


        :param position: The position of this NativeShapeField.
        :type: int
        """
        self._position = position

    @property
    def default_value_string(self):
        """
        Gets the default_value_string of this NativeShapeField.
        The default value.


        :return: The default_value_string of this NativeShapeField.
        :rtype: str
        """
        return self._default_value_string

    @default_value_string.setter
    def default_value_string(self, default_value_string):
        """
        Sets the default_value_string of this NativeShapeField.
        The default value.


        :param default_value_string: The default_value_string of this NativeShapeField.
        :type: str
        """
        self._default_value_string = default_value_string

    @property
    def is_mandatory(self):
        """
        Gets the is_mandatory of this NativeShapeField.
        Specifies whether the field is mandatory.


        :return: The is_mandatory of this NativeShapeField.
        :rtype: bool
        """
        return self._is_mandatory

    @is_mandatory.setter
    def is_mandatory(self, is_mandatory):
        """
        Sets the is_mandatory of this NativeShapeField.
        Specifies whether the field is mandatory.


        :param is_mandatory: The is_mandatory of this NativeShapeField.
        :type: bool
        """
        self._is_mandatory = is_mandatory

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .drg_attachment_network_details import DrgAttachmentNetworkDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VcnDrgAttachmentNetworkDetails(DrgAttachmentNetworkDetails):
    """
    Specifies details within the VCN.
    """

    #: A constant which can be used with the vcn_route_type property of a VcnDrgAttachmentNetworkDetails.
    #: This constant has a value of "VCN_CIDRS"
    VCN_ROUTE_TYPE_VCN_CIDRS = "VCN_CIDRS"

    #: A constant which can be used with the vcn_route_type property of a VcnDrgAttachmentNetworkDetails.
    #: This constant has a value of "SUBNET_CIDRS"
    VCN_ROUTE_TYPE_SUBNET_CIDRS = "SUBNET_CIDRS"

    def __init__(self, **kwargs):
        """
        Initializes a new VcnDrgAttachmentNetworkDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.core.models.VcnDrgAttachmentNetworkDetails.type` attribute
        of this class is ``VCN`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this VcnDrgAttachmentNetworkDetails.
            Allowed values for this property are: "VCN", "IPSEC_TUNNEL", "VIRTUAL_CIRCUIT", "REMOTE_PEERING_CONNECTION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param id:
            The value to assign to the id property of this VcnDrgAttachmentNetworkDetails.
        :type id: str

        :param route_table_id:
            The value to assign to the route_table_id property of this VcnDrgAttachmentNetworkDetails.
        :type route_table_id: str

        :param vcn_route_type:
            The value to assign to the vcn_route_type property of this VcnDrgAttachmentNetworkDetails.
            Allowed values for this property are: "VCN_CIDRS", "SUBNET_CIDRS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type vcn_route_type: str

        """
        self.swagger_types = {
            'type': 'str',
            'id': 'str',
            'route_table_id': 'str',
            'vcn_route_type': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'id': 'id',
            'route_table_id': 'routeTableId',
            'vcn_route_type': 'vcnRouteType'
        }

        self._type = None
        self._id = None
        self._route_table_id = None
        self._vcn_route_type = None
        self._type = 'VCN'

    @property
    def route_table_id(self):
        """
        Gets the route_table_id of this VcnDrgAttachmentNetworkDetails.
        The `OCID`__ of the route table the DRG attachment is using.

        For information about why you would associate a route table with a DRG attachment, see:

          * `Transit Routing: Access to Multiple VCNs in Same Region`__
          * `Transit Routing: Private Access to Oracle Services`__

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/transitrouting.htm
        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/transitroutingoracleservices.htm


        :return: The route_table_id of this VcnDrgAttachmentNetworkDetails.
        :rtype: str
        """
        return self._route_table_id

    @route_table_id.setter
    def route_table_id(self, route_table_id):
        """
        Sets the route_table_id of this VcnDrgAttachmentNetworkDetails.
        The `OCID`__ of the route table the DRG attachment is using.

        For information about why you would associate a route table with a DRG attachment, see:

          * `Transit Routing: Access to Multiple VCNs in Same Region`__
          * `Transit Routing: Private Access to Oracle Services`__

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/transitrouting.htm
        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/transitroutingoracleservices.htm


        :param route_table_id: The route_table_id of this VcnDrgAttachmentNetworkDetails.
        :type: str
        """
        self._route_table_id = route_table_id

    @property
    def vcn_route_type(self):
        """
        Gets the vcn_route_type of this VcnDrgAttachmentNetworkDetails.
        Indicates whether the VCN CIDRs or the individual subnet CIDRs are imported from the attachment.
        Routes from the VCN ingress route table are always imported.

        Allowed values for this property are: "VCN_CIDRS", "SUBNET_CIDRS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The vcn_route_type of this VcnDrgAttachmentNetworkDetails.
        :rtype: str
        """
        return self._vcn_route_type

    @vcn_route_type.setter
    def vcn_route_type(self, vcn_route_type):
        """
        Sets the vcn_route_type of this VcnDrgAttachmentNetworkDetails.
        Indicates whether the VCN CIDRs or the individual subnet CIDRs are imported from the attachment.
        Routes from the VCN ingress route table are always imported.


        :param vcn_route_type: The vcn_route_type of this VcnDrgAttachmentNetworkDetails.
        :type: str
        """
        allowed_values = ["VCN_CIDRS", "SUBNET_CIDRS"]
        if not value_allowed_none_or_none_sentinel(vcn_route_type, allowed_values):
            vcn_route_type = 'UNKNOWN_ENUM_VALUE'
        self._vcn_route_type = vcn_route_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .ca_bundle import CaBundle
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LocalFileCaBundle(CaBundle):
    """
    CA Bundle from the filesystem.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LocalFileCaBundle object with values from keyword arguments. The default value of the :py:attr:`~oci.service_mesh.models.LocalFileCaBundle.type` attribute
        of this class is ``LOCAL_FILE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this LocalFileCaBundle.
            Allowed values for this property are: "OCI_CERTIFICATES", "LOCAL_FILE"
        :type type: str

        :param secret_name:
            The value to assign to the secret_name property of this LocalFileCaBundle.
        :type secret_name: str

        """
        self.swagger_types = {
            'type': 'str',
            'secret_name': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'secret_name': 'secretName'
        }

        self._type = None
        self._secret_name = None
        self._type = 'LOCAL_FILE'

    @property
    def secret_name(self):
        """
        Gets the secret_name of this LocalFileCaBundle.
        Name of the secret.
        For Kubernetes this will be the name of an opaque Kubernetes secret with key ca.crt.
        For other platforms the secret must be mounted at: /etc/oci/secrets/${secretName}/ca.crt


        :return: The secret_name of this LocalFileCaBundle.
        :rtype: str
        """
        return self._secret_name

    @secret_name.setter
    def secret_name(self, secret_name):
        """
        Sets the secret_name of this LocalFileCaBundle.
        Name of the secret.
        For Kubernetes this will be the name of an opaque Kubernetes secret with key ca.crt.
        For other platforms the secret must be mounted at: /etc/oci/secrets/${secretName}/ca.crt


        :param secret_name: The secret_name of this LocalFileCaBundle.
        :type: str
        """
        self._secret_name = secret_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Quota(object):
    """
    Quota policy for a usage plan.
    """

    #: A constant which can be used with the unit property of a Quota.
    #: This constant has a value of "MINUTE"
    UNIT_MINUTE = "MINUTE"

    #: A constant which can be used with the unit property of a Quota.
    #: This constant has a value of "HOUR"
    UNIT_HOUR = "HOUR"

    #: A constant which can be used with the unit property of a Quota.
    #: This constant has a value of "DAY"
    UNIT_DAY = "DAY"

    #: A constant which can be used with the unit property of a Quota.
    #: This constant has a value of "WEEK"
    UNIT_WEEK = "WEEK"

    #: A constant which can be used with the unit property of a Quota.
    #: This constant has a value of "MONTH"
    UNIT_MONTH = "MONTH"

    #: A constant which can be used with the reset_policy property of a Quota.
    #: This constant has a value of "CALENDAR"
    RESET_POLICY_CALENDAR = "CALENDAR"

    #: A constant which can be used with the operation_on_breach property of a Quota.
    #: This constant has a value of "REJECT"
    OPERATION_ON_BREACH_REJECT = "REJECT"

    #: A constant which can be used with the operation_on_breach property of a Quota.
    #: This constant has a value of "ALLOW"
    OPERATION_ON_BREACH_ALLOW = "ALLOW"

    def __init__(self, **kwargs):
        """
        Initializes a new Quota object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param value:
            The value to assign to the value property of this Quota.
        :type value: int

        :param unit:
            The value to assign to the unit property of this Quota.
            Allowed values for this property are: "MINUTE", "HOUR", "DAY", "WEEK", "MONTH", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type unit: str

        :param reset_policy:
            The value to assign to the reset_policy property of this Quota.
            Allowed values for this property are: "CALENDAR", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type reset_policy: str

        :param operation_on_breach:
            The value to assign to the operation_on_breach property of this Quota.
            Allowed values for this property are: "REJECT", "ALLOW", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type operation_on_breach: str

        """
        self.swagger_types = {
            'value': 'int',
            'unit': 'str',
            'reset_policy': 'str',
            'operation_on_breach': 'str'
        }

        self.attribute_map = {
            'value': 'value',
            'unit': 'unit',
            'reset_policy': 'resetPolicy',
            'operation_on_breach': 'operationOnBreach'
        }

        self._value = None
        self._unit = None
        self._reset_policy = None
        self._operation_on_breach = None

    @property
    def value(self):
        """
        **[Required]** Gets the value of this Quota.
        The number of requests that can be made per time period.


        :return: The value of this Quota.
        :rtype: int
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this Quota.
        The number of requests that can be made per time period.


        :param value: The value of this Quota.
        :type: int
        """
        self._value = value

    @property
    def unit(self):
        """
        **[Required]** Gets the unit of this Quota.
        The unit of time over which quotas are calculated.
        Example: `MINUTE` or `MONTH`

        Allowed values for this property are: "MINUTE", "HOUR", "DAY", "WEEK", "MONTH", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The unit of this Quota.
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """
        Sets the unit of this Quota.
        The unit of time over which quotas are calculated.
        Example: `MINUTE` or `MONTH`


        :param unit: The unit of this Quota.
        :type: str
        """
        allowed_values = ["MINUTE", "HOUR", "DAY", "WEEK", "MONTH"]
        if not value_allowed_none_or_none_sentinel(unit, allowed_values):
            unit = 'UNKNOWN_ENUM_VALUE'
        self._unit = unit

    @property
    def reset_policy(self):
        """
        **[Required]** Gets the reset_policy of this Quota.
        The policy that controls when quotas will reset.
        Example: `CALENDAR`

        Allowed values for this property are: "CALENDAR", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The reset_policy of this Quota.
        :rtype: str
        """
        return self._reset_policy

    @reset_policy.setter
    def reset_policy(self, reset_policy):
        """
        Sets the reset_policy of this Quota.
        The policy that controls when quotas will reset.
        Example: `CALENDAR`


        :param reset_policy: The reset_policy of this Quota.
        :type: str
        """
        allowed_values = ["CALENDAR"]
        if not value_allowed_none_or_none_sentinel(reset_policy, allowed_values):
            reset_policy = 'UNKNOWN_ENUM_VALUE'
        self._reset_policy = reset_policy

    @property
    def operation_on_breach(self):
        """
        **[Required]** Gets the operation_on_breach of this Quota.
        What the usage plan will do when a quota is breached:
        `REJECT` will allow no further requests
        `ALLOW` will continue to allow further requests

        Allowed values for this property are: "REJECT", "ALLOW", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The operation_on_breach of this Quota.
        :rtype: str
        """
        return self._operation_on_breach

    @operation_on_breach.setter
    def operation_on_breach(self, operation_on_breach):
        """
        Sets the operation_on_breach of this Quota.
        What the usage plan will do when a quota is breached:
        `REJECT` will allow no further requests
        `ALLOW` will continue to allow further requests


        :param operation_on_breach: The operation_on_breach of this Quota.
        :type: str
        """
        allowed_values = ["REJECT", "ALLOW"]
        if not value_allowed_none_or_none_sentinel(operation_on_breach, allowed_values):
            operation_on_breach = 'UNKNOWN_ENUM_VALUE'
        self._operation_on_breach = operation_on_breach

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TablespaceStorageSize(object):
    """
    Storage size.
    """

    #: A constant which can be used with the unit property of a TablespaceStorageSize.
    #: This constant has a value of "BYTES"
    UNIT_BYTES = "BYTES"

    #: A constant which can be used with the unit property of a TablespaceStorageSize.
    #: This constant has a value of "KILOBYTES"
    UNIT_KILOBYTES = "KILOBYTES"

    #: A constant which can be used with the unit property of a TablespaceStorageSize.
    #: This constant has a value of "MEGABYTES"
    UNIT_MEGABYTES = "MEGABYTES"

    #: A constant which can be used with the unit property of a TablespaceStorageSize.
    #: This constant has a value of "GIGABYTES"
    UNIT_GIGABYTES = "GIGABYTES"

    #: A constant which can be used with the unit property of a TablespaceStorageSize.
    #: This constant has a value of "TERABYTES"
    UNIT_TERABYTES = "TERABYTES"

    def __init__(self, **kwargs):
        """
        Initializes a new TablespaceStorageSize object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param size:
            The value to assign to the size property of this TablespaceStorageSize.
        :type size: float

        :param unit:
            The value to assign to the unit property of this TablespaceStorageSize.
            Allowed values for this property are: "BYTES", "KILOBYTES", "MEGABYTES", "GIGABYTES", "TERABYTES"
        :type unit: str

        """
        self.swagger_types = {
            'size': 'float',
            'unit': 'str'
        }

        self.attribute_map = {
            'size': 'size',
            'unit': 'unit'
        }

        self._size = None
        self._unit = None

    @property
    def size(self):
        """
        **[Required]** Gets the size of this TablespaceStorageSize.
        Storage size number in bytes, kilobytes, megabytes, gigabytes, or terabytes.


        :return: The size of this TablespaceStorageSize.
        :rtype: float
        """
        return self._size

    @size.setter
    def size(self, size):
        """
        Sets the size of this TablespaceStorageSize.
        Storage size number in bytes, kilobytes, megabytes, gigabytes, or terabytes.


        :param size: The size of this TablespaceStorageSize.
        :type: float
        """
        self._size = size

    @property
    def unit(self):
        """
        Gets the unit of this TablespaceStorageSize.
        Storage size unit: bytes, kilobytes, megabytes, gigabytes, or terabytes.

        Allowed values for this property are: "BYTES", "KILOBYTES", "MEGABYTES", "GIGABYTES", "TERABYTES"


        :return: The unit of this TablespaceStorageSize.
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """
        Sets the unit of this TablespaceStorageSize.
        Storage size unit: bytes, kilobytes, megabytes, gigabytes, or terabytes.


        :param unit: The unit of this TablespaceStorageSize.
        :type: str
        """
        allowed_values = ["BYTES", "KILOBYTES", "MEGABYTES", "GIGABYTES", "TERABYTES"]
        if not value_allowed_none_or_none_sentinel(unit, allowed_values):
            raise ValueError(
                "Invalid value for `unit`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._unit = unit

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SqlTuningAdvisorTaskSummary(object):
    """
    The summary of a SQL Tuning Advisor task.
    """

    #: A constant which can be used with the task_status property of a SqlTuningAdvisorTaskSummary.
    #: This constant has a value of "COMPLETED"
    TASK_STATUS_COMPLETED = "COMPLETED"

    #: A constant which can be used with the task_status property of a SqlTuningAdvisorTaskSummary.
    #: This constant has a value of "INITIAL"
    TASK_STATUS_INITIAL = "INITIAL"

    #: A constant which can be used with the task_status property of a SqlTuningAdvisorTaskSummary.
    #: This constant has a value of "EXECUTING"
    TASK_STATUS_EXECUTING = "EXECUTING"

    #: A constant which can be used with the task_status property of a SqlTuningAdvisorTaskSummary.
    #: This constant has a value of "INTERRUPTED"
    TASK_STATUS_INTERRUPTED = "INTERRUPTED"

    #: A constant which can be used with the task_status property of a SqlTuningAdvisorTaskSummary.
    #: This constant has a value of "ERROR"
    TASK_STATUS_ERROR = "ERROR"

    def __init__(self, **kwargs):
        """
        Initializes a new SqlTuningAdvisorTaskSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param sql_tuning_advisor_task_id:
            The value to assign to the sql_tuning_advisor_task_id property of this SqlTuningAdvisorTaskSummary.
        :type sql_tuning_advisor_task_id: int

        :param instance_id:
            The value to assign to the instance_id property of this SqlTuningAdvisorTaskSummary.
        :type instance_id: int

        :param name:
            The value to assign to the name property of this SqlTuningAdvisorTaskSummary.
        :type name: str

        :param description:
            The value to assign to the description property of this SqlTuningAdvisorTaskSummary.
        :type description: str

        :param owner:
            The value to assign to the owner property of this SqlTuningAdvisorTaskSummary.
        :type owner: str

        :param time_created:
            The value to assign to the time_created property of this SqlTuningAdvisorTaskSummary.
        :type time_created: datetime

        :param task_status:
            The value to assign to the task_status property of this SqlTuningAdvisorTaskSummary.
            Allowed values for this property are: "COMPLETED", "INITIAL", "EXECUTING", "INTERRUPTED", "ERROR", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type task_status: str

        :param days_to_expire:
            The value to assign to the days_to_expire property of this SqlTuningAdvisorTaskSummary.
        :type days_to_expire: int

        :param time_execution_started:
            The value to assign to the time_execution_started property of this SqlTuningAdvisorTaskSummary.
        :type time_execution_started: datetime

        :param time_execution_ended:
            The value to assign to the time_execution_ended property of this SqlTuningAdvisorTaskSummary.
        :type time_execution_ended: datetime

        :param total_sql_statements:
            The value to assign to the total_sql_statements property of this SqlTuningAdvisorTaskSummary.
        :type total_sql_statements: int

        :param recommendation_count:
            The value to assign to the recommendation_count property of this SqlTuningAdvisorTaskSummary.
        :type recommendation_count: int

        """
        self.swagger_types = {
            'sql_tuning_advisor_task_id': 'int',
            'instance_id': 'int',
            'name': 'str',
            'description': 'str',
            'owner': 'str',
            'time_created': 'datetime',
            'task_status': 'str',
            'days_to_expire': 'int',
            'time_execution_started': 'datetime',
            'time_execution_ended': 'datetime',
            'total_sql_statements': 'int',
            'recommendation_count': 'int'
        }

        self.attribute_map = {
            'sql_tuning_advisor_task_id': 'sqlTuningAdvisorTaskId',
            'instance_id': 'instanceId',
            'name': 'name',
            'description': 'description',
            'owner': 'owner',
            'time_created': 'timeCreated',
            'task_status': 'taskStatus',
            'days_to_expire': 'daysToExpire',
            'time_execution_started': 'timeExecutionStarted',
            'time_execution_ended': 'timeExecutionEnded',
            'total_sql_statements': 'totalSqlStatements',
            'recommendation_count': 'recommendationCount'
        }

        self._sql_tuning_advisor_task_id = None
        self._instance_id = None
        self._name = None
        self._description = None
        self._owner = None
        self._time_created = None
        self._task_status = None
        self._days_to_expire = None
        self._time_execution_started = None
        self._time_execution_ended = None
        self._total_sql_statements = None
        self._recommendation_count = None

    @property
    def sql_tuning_advisor_task_id(self):
        """
        **[Required]** Gets the sql_tuning_advisor_task_id of this SqlTuningAdvisorTaskSummary.
        The unique identifier of the SQL Tuning Advisor task. This is not the `OCID`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The sql_tuning_advisor_task_id of this SqlTuningAdvisorTaskSummary.
        :rtype: int
        """
        return self._sql_tuning_advisor_task_id

    @sql_tuning_advisor_task_id.setter
    def sql_tuning_advisor_task_id(self, sql_tuning_advisor_task_id):
        """
        Sets the sql_tuning_advisor_task_id of this SqlTuningAdvisorTaskSummary.
        The unique identifier of the SQL Tuning Advisor task. This is not the `OCID`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param sql_tuning_advisor_task_id: The sql_tuning_advisor_task_id of this SqlTuningAdvisorTaskSummary.
        :type: int
        """
        self._sql_tuning_advisor_task_id = sql_tuning_advisor_task_id

    @property
    def instance_id(self):
        """
        Gets the instance_id of this SqlTuningAdvisorTaskSummary.
        The instance ID of the SQL Tuning Advisor task. This is not the `OCID`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The instance_id of this SqlTuningAdvisorTaskSummary.
        :rtype: int
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """
        Sets the instance_id of this SqlTuningAdvisorTaskSummary.
        The instance ID of the SQL Tuning Advisor task. This is not the `OCID`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param instance_id: The instance_id of this SqlTuningAdvisorTaskSummary.
        :type: int
        """
        self._instance_id = instance_id

    @property
    def name(self):
        """
        Gets the name of this SqlTuningAdvisorTaskSummary.
        The name of the SQL Tuning Advisor task.


        :return: The name of this SqlTuningAdvisorTaskSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this SqlTuningAdvisorTaskSummary.
        The name of the SQL Tuning Advisor task.


        :param name: The name of this SqlTuningAdvisorTaskSummary.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this SqlTuningAdvisorTaskSummary.
        The description of the SQL Tuning Advisor task.


        :return: The description of this SqlTuningAdvisorTaskSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this SqlTuningAdvisorTaskSummary.
        The description of the SQL Tuning Advisor task.


        :param description: The description of this SqlTuningAdvisorTaskSummary.
        :type: str
        """
        self._description = description

    @property
    def owner(self):
        """
        Gets the owner of this SqlTuningAdvisorTaskSummary.
        The owner of the SQL Tuning Advisor task.


        :return: The owner of this SqlTuningAdvisorTaskSummary.
        :rtype: str
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """
        Sets the owner of this SqlTuningAdvisorTaskSummary.
        The owner of the SQL Tuning Advisor task.


        :param owner: The owner of this SqlTuningAdvisorTaskSummary.
        :type: str
        """
        self._owner = owner

    @property
    def time_created(self):
        """
        Gets the time_created of this SqlTuningAdvisorTaskSummary.
        The Creation date of the SQL Tuning Advisor task.


        :return: The time_created of this SqlTuningAdvisorTaskSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this SqlTuningAdvisorTaskSummary.
        The Creation date of the SQL Tuning Advisor task.


        :param time_created: The time_created of this SqlTuningAdvisorTaskSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def task_status(self):
        """
        Gets the task_status of this SqlTuningAdvisorTaskSummary.
        The status of the SQL Tuning Advisor task.

        Allowed values for this property are: "COMPLETED", "INITIAL", "EXECUTING", "INTERRUPTED", "ERROR", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The task_status of this SqlTuningAdvisorTaskSummary.
        :rtype: str
        """
        return self._task_status

    @task_status.setter
    def task_status(self, task_status):
        """
        Sets the task_status of this SqlTuningAdvisorTaskSummary.
        The status of the SQL Tuning Advisor task.


        :param task_status: The task_status of this SqlTuningAdvisorTaskSummary.
        :type: str
        """
        allowed_values = ["COMPLETED", "INITIAL", "EXECUTING", "INTERRUPTED", "ERROR"]
        if not value_allowed_none_or_none_sentinel(task_status, allowed_values):
            task_status = 'UNKNOWN_ENUM_VALUE'
        self._task_status = task_status

    @property
    def days_to_expire(self):
        """
        Gets the days_to_expire of this SqlTuningAdvisorTaskSummary.
        The number of days left before the task expires. If the value equals -1, then the task has no expiration time (UNLIMITED).


        :return: The days_to_expire of this SqlTuningAdvisorTaskSummary.
        :rtype: int
        """
        return self._days_to_expire

    @days_to_expire.setter
    def days_to_expire(self, days_to_expire):
        """
        Sets the days_to_expire of this SqlTuningAdvisorTaskSummary.
        The number of days left before the task expires. If the value equals -1, then the task has no expiration time (UNLIMITED).


        :param days_to_expire: The days_to_expire of this SqlTuningAdvisorTaskSummary.
        :type: int
        """
        self._days_to_expire = days_to_expire

    @property
    def time_execution_started(self):
        """
        Gets the time_execution_started of this SqlTuningAdvisorTaskSummary.
        The start time of the task execution.


        :return: The time_execution_started of this SqlTuningAdvisorTaskSummary.
        :rtype: datetime
        """
        return self._time_execution_started

    @time_execution_started.setter
    def time_execution_started(self, time_execution_started):
        """
        Sets the time_execution_started of this SqlTuningAdvisorTaskSummary.
        The start time of the task execution.


        :param time_execution_started: The time_execution_started of this SqlTuningAdvisorTaskSummary.
        :type: datetime
        """
        self._time_execution_started = time_execution_started

    @property
    def time_execution_ended(self):
        """
        Gets the time_execution_ended of this SqlTuningAdvisorTaskSummary.
        The end time of the task execution.


        :return: The time_execution_ended of this SqlTuningAdvisorTaskSummary.
        :rtype: datetime
        """
        return self._time_execution_ended

    @time_execution_ended.setter
    def time_execution_ended(self, time_execution_ended):
        """
        Sets the time_execution_ended of this SqlTuningAdvisorTaskSummary.
        The end time of the task execution.


        :param time_execution_ended: The time_execution_ended of this SqlTuningAdvisorTaskSummary.
        :type: datetime
        """
        self._time_execution_ended = time_execution_ended

    @property
    def total_sql_statements(self):
        """
        Gets the total_sql_statements of this SqlTuningAdvisorTaskSummary.
        The total number of SQL statements related to the SQL Tuning Advisor task.


        :return: The total_sql_statements of this SqlTuningAdvisorTaskSummary.
        :rtype: int
        """
        return self._total_sql_statements

    @total_sql_statements.setter
    def total_sql_statements(self, total_sql_statements):
        """
        Sets the total_sql_statements of this SqlTuningAdvisorTaskSummary.
        The total number of SQL statements related to the SQL Tuning Advisor task.


        :param total_sql_statements: The total_sql_statements of this SqlTuningAdvisorTaskSummary.
        :type: int
        """
        self._total_sql_statements = total_sql_statements

    @property
    def recommendation_count(self):
        """
        Gets the recommendation_count of this SqlTuningAdvisorTaskSummary.
        The number of recommendations provided for the SQL Tuning Advisor task.


        :return: The recommendation_count of this SqlTuningAdvisorTaskSummary.
        :rtype: int
        """
        return self._recommendation_count

    @recommendation_count.setter
    def recommendation_count(self, recommendation_count):
        """
        Sets the recommendation_count of this SqlTuningAdvisorTaskSummary.
        The number of recommendations provided for the SQL Tuning Advisor task.


        :param recommendation_count: The recommendation_count of this SqlTuningAdvisorTaskSummary.
        :type: int
        """
        self._recommendation_count = recommendation_count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateDatabaseLinkDetails(object):
    """
    Optional details for updating a network database link from OCI database to on-premise database.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateDatabaseLinkDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this UpdateDatabaseLinkDetails.
        :type name: str

        :param wallet_bucket:
            The value to assign to the wallet_bucket property of this UpdateDatabaseLinkDetails.
        :type wallet_bucket: oci.database_migration.models.UpdateObjectStoreBucket

        """
        self.swagger_types = {
            'name': 'str',
            'wallet_bucket': 'UpdateObjectStoreBucket'
        }

        self.attribute_map = {
            'name': 'name',
            'wallet_bucket': 'walletBucket'
        }

        self._name = None
        self._wallet_bucket = None

    @property
    def name(self):
        """
        Gets the name of this UpdateDatabaseLinkDetails.
        Name of database link from OCI database to on-premise database. ODMS will create link, if the link does not already exist.


        :return: The name of this UpdateDatabaseLinkDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this UpdateDatabaseLinkDetails.
        Name of database link from OCI database to on-premise database. ODMS will create link, if the link does not already exist.


        :param name: The name of this UpdateDatabaseLinkDetails.
        :type: str
        """
        self._name = name

    @property
    def wallet_bucket(self):
        """
        Gets the wallet_bucket of this UpdateDatabaseLinkDetails.

        :return: The wallet_bucket of this UpdateDatabaseLinkDetails.
        :rtype: oci.database_migration.models.UpdateObjectStoreBucket
        """
        return self._wallet_bucket

    @wallet_bucket.setter
    def wallet_bucket(self, wallet_bucket):
        """
        Sets the wallet_bucket of this UpdateDatabaseLinkDetails.

        :param wallet_bucket: The wallet_bucket of this UpdateDatabaseLinkDetails.
        :type: oci.database_migration.models.UpdateObjectStoreBucket
        """
        self._wallet_bucket = wallet_bucket

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RequestSummarizedTrendResourceRiskScoresDetails(object):
    """
    ResourceRiskScores filter.
    """

    #: A constant which can be used with the filter property of a RequestSummarizedTrendResourceRiskScoresDetails.
    #: This constant has a value of "PROBLEM_ID"
    FILTER_PROBLEM_ID = "PROBLEM_ID"

    #: A constant which can be used with the filter property of a RequestSummarizedTrendResourceRiskScoresDetails.
    #: This constant has a value of "RESOURCE_PROFILE_ID"
    FILTER_RESOURCE_PROFILE_ID = "RESOURCE_PROFILE_ID"

    def __init__(self, **kwargs):
        """
        Initializes a new RequestSummarizedTrendResourceRiskScoresDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param filter:
            The value to assign to the filter property of this RequestSummarizedTrendResourceRiskScoresDetails.
            Allowed values for this property are: "PROBLEM_ID", "RESOURCE_PROFILE_ID"
        :type filter: str

        :param filter_id:
            The value to assign to the filter_id property of this RequestSummarizedTrendResourceRiskScoresDetails.
        :type filter_id: str

        """
        self.swagger_types = {
            'filter': 'str',
            'filter_id': 'str'
        }

        self.attribute_map = {
            'filter': 'filter',
            'filter_id': 'filterId'
        }

        self._filter = None
        self._filter_id = None

    @property
    def filter(self):
        """
        **[Required]** Gets the filter of this RequestSummarizedTrendResourceRiskScoresDetails.
        The filter type.

        Allowed values for this property are: "PROBLEM_ID", "RESOURCE_PROFILE_ID"


        :return: The filter of this RequestSummarizedTrendResourceRiskScoresDetails.
        :rtype: str
        """
        return self._filter

    @filter.setter
    def filter(self, filter):
        """
        Sets the filter of this RequestSummarizedTrendResourceRiskScoresDetails.
        The filter type.


        :param filter: The filter of this RequestSummarizedTrendResourceRiskScoresDetails.
        :type: str
        """
        allowed_values = ["PROBLEM_ID", "RESOURCE_PROFILE_ID"]
        if not value_allowed_none_or_none_sentinel(filter, allowed_values):
            raise ValueError(
                "Invalid value for `filter`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._filter = filter

    @property
    def filter_id(self):
        """
        **[Required]** Gets the filter_id of this RequestSummarizedTrendResourceRiskScoresDetails.
        Id to be passed in to filter the risk scores.


        :return: The filter_id of this RequestSummarizedTrendResourceRiskScoresDetails.
        :rtype: str
        """
        return self._filter_id

    @filter_id.setter
    def filter_id(self, filter_id):
        """
        Sets the filter_id of this RequestSummarizedTrendResourceRiskScoresDetails.
        Id to be passed in to filter the risk scores.


        :param filter_id: The filter_id of this RequestSummarizedTrendResourceRiskScoresDetails.
        :type: str
        """
        self._filter_id = filter_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AutoScalePolicyDetails(object):
    """
    Details of an autoscale policy.

    You can create following types of autoscaling policies:

    - **MetricBasedVerticalScalingPolicy:** Vertical autoscaling action is triggered when a performance metric exceeds a threshold
    - **MetricBasedHorizontalScalingPolicy:** Horizontal autoscaling action is triggered when a performance metric exceeds a threshold
    - **ScheduleBasedVerticalScalingPolicy:** Vertical autoscaling action is triggered at the specific times that you schedule.
    - **ScheduleBasedHorizontalScalingPolicy:** Horizontal autoscaling action is triggered at the specific times that you schedule.
    """

    #: A constant which can be used with the policy_type property of a AutoScalePolicyDetails.
    #: This constant has a value of "METRIC_BASED_VERTICAL_SCALING_POLICY"
    POLICY_TYPE_METRIC_BASED_VERTICAL_SCALING_POLICY = "METRIC_BASED_VERTICAL_SCALING_POLICY"

    #: A constant which can be used with the policy_type property of a AutoScalePolicyDetails.
    #: This constant has a value of "METRIC_BASED_HORIZONTAL_SCALING_POLICY"
    POLICY_TYPE_METRIC_BASED_HORIZONTAL_SCALING_POLICY = "METRIC_BASED_HORIZONTAL_SCALING_POLICY"

    #: A constant which can be used with the policy_type property of a AutoScalePolicyDetails.
    #: This constant has a value of "SCHEDULE_BASED_VERTICAL_SCALING_POLICY"
    POLICY_TYPE_SCHEDULE_BASED_VERTICAL_SCALING_POLICY = "SCHEDULE_BASED_VERTICAL_SCALING_POLICY"

    #: A constant which can be used with the policy_type property of a AutoScalePolicyDetails.
    #: This constant has a value of "SCHEDULE_BASED_HORIZONTAL_SCALING_POLICY"
    POLICY_TYPE_SCHEDULE_BASED_HORIZONTAL_SCALING_POLICY = "SCHEDULE_BASED_HORIZONTAL_SCALING_POLICY"

    #: A constant which can be used with the trigger_type property of a AutoScalePolicyDetails.
    #: This constant has a value of "METRIC_BASED"
    TRIGGER_TYPE_METRIC_BASED = "METRIC_BASED"

    #: A constant which can be used with the trigger_type property of a AutoScalePolicyDetails.
    #: This constant has a value of "SCHEDULE_BASED"
    TRIGGER_TYPE_SCHEDULE_BASED = "SCHEDULE_BASED"

    #: A constant which can be used with the action_type property of a AutoScalePolicyDetails.
    #: This constant has a value of "VERTICAL_SCALING"
    ACTION_TYPE_VERTICAL_SCALING = "VERTICAL_SCALING"

    #: A constant which can be used with the action_type property of a AutoScalePolicyDetails.
    #: This constant has a value of "HORIZONTAL_SCALING"
    ACTION_TYPE_HORIZONTAL_SCALING = "HORIZONTAL_SCALING"

    def __init__(self, **kwargs):
        """
        Initializes a new AutoScalePolicyDetails object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.bds.models.MetricBasedVerticalScalingPolicyDetails`
        * :class:`~oci.bds.models.ScheduleBasedVerticalScalingPolicyDetails`
        * :class:`~oci.bds.models.ScheduleBasedHorizontalScalingPolicyDetails`
        * :class:`~oci.bds.models.MetricBasedHorizontalScalingPolicyDetails`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param policy_type:
            The value to assign to the policy_type property of this AutoScalePolicyDetails.
            Allowed values for this property are: "METRIC_BASED_VERTICAL_SCALING_POLICY", "METRIC_BASED_HORIZONTAL_SCALING_POLICY", "SCHEDULE_BASED_VERTICAL_SCALING_POLICY", "SCHEDULE_BASED_HORIZONTAL_SCALING_POLICY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type policy_type: str

        :param trigger_type:
            The value to assign to the trigger_type property of this AutoScalePolicyDetails.
            Allowed values for this property are: "METRIC_BASED", "SCHEDULE_BASED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type trigger_type: str

        :param action_type:
            The value to assign to the action_type property of this AutoScalePolicyDetails.
            Allowed values for this property are: "VERTICAL_SCALING", "HORIZONTAL_SCALING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type action_type: str

        """
        self.swagger_types = {
            'policy_type': 'str',
            'trigger_type': 'str',
            'action_type': 'str'
        }

        self.attribute_map = {
            'policy_type': 'policyType',
            'trigger_type': 'triggerType',
            'action_type': 'actionType'
        }

        self._policy_type = None
        self._trigger_type = None
        self._action_type = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['policyType']

        if type == 'METRIC_BASED_VERTICAL_SCALING_POLICY':
            return 'MetricBasedVerticalScalingPolicyDetails'

        if type == 'SCHEDULE_BASED_VERTICAL_SCALING_POLICY':
            return 'ScheduleBasedVerticalScalingPolicyDetails'

        if type == 'SCHEDULE_BASED_HORIZONTAL_SCALING_POLICY':
            return 'ScheduleBasedHorizontalScalingPolicyDetails'

        if type == 'METRIC_BASED_HORIZONTAL_SCALING_POLICY':
            return 'MetricBasedHorizontalScalingPolicyDetails'
        else:
            return 'AutoScalePolicyDetails'

    @property
    def policy_type(self):
        """
        **[Required]** Gets the policy_type of this AutoScalePolicyDetails.
        Type of autoscaling policy.

        Allowed values for this property are: "METRIC_BASED_VERTICAL_SCALING_POLICY", "METRIC_BASED_HORIZONTAL_SCALING_POLICY", "SCHEDULE_BASED_VERTICAL_SCALING_POLICY", "SCHEDULE_BASED_HORIZONTAL_SCALING_POLICY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The policy_type of this AutoScalePolicyDetails.
        :rtype: str
        """
        return self._policy_type

    @policy_type.setter
    def policy_type(self, policy_type):
        """
        Sets the policy_type of this AutoScalePolicyDetails.
        Type of autoscaling policy.


        :param policy_type: The policy_type of this AutoScalePolicyDetails.
        :type: str
        """
        allowed_values = ["METRIC_BASED_VERTICAL_SCALING_POLICY", "METRIC_BASED_HORIZONTAL_SCALING_POLICY", "SCHEDULE_BASED_VERTICAL_SCALING_POLICY", "SCHEDULE_BASED_HORIZONTAL_SCALING_POLICY"]
        if not value_allowed_none_or_none_sentinel(policy_type, allowed_values):
            policy_type = 'UNKNOWN_ENUM_VALUE'
        self._policy_type = policy_type

    @property
    def trigger_type(self):
        """
        **[Required]** Gets the trigger_type of this AutoScalePolicyDetails.
        The type of autoscaling trigger.

        Allowed values for this property are: "METRIC_BASED", "SCHEDULE_BASED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The trigger_type of this AutoScalePolicyDetails.
        :rtype: str
        """
        return self._trigger_type

    @trigger_type.setter
    def trigger_type(self, trigger_type):
        """
        Sets the trigger_type of this AutoScalePolicyDetails.
        The type of autoscaling trigger.


        :param trigger_type: The trigger_type of this AutoScalePolicyDetails.
        :type: str
        """
        allowed_values = ["METRIC_BASED", "SCHEDULE_BASED"]
        if not value_allowed_none_or_none_sentinel(trigger_type, allowed_values):
            trigger_type = 'UNKNOWN_ENUM_VALUE'
        self._trigger_type = trigger_type

    @property
    def action_type(self):
        """
        **[Required]** Gets the action_type of this AutoScalePolicyDetails.
        The type of autoscaling action to take.

        Allowed values for this property are: "VERTICAL_SCALING", "HORIZONTAL_SCALING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The action_type of this AutoScalePolicyDetails.
        :rtype: str
        """
        return self._action_type

    @action_type.setter
    def action_type(self, action_type):
        """
        Sets the action_type of this AutoScalePolicyDetails.
        The type of autoscaling action to take.


        :param action_type: The action_type of this AutoScalePolicyDetails.
        :type: str
        """
        allowed_values = ["VERTICAL_SCALING", "HORIZONTAL_SCALING"]
        if not value_allowed_none_or_none_sentinel(action_type, allowed_values):
            action_type = 'UNKNOWN_ENUM_VALUE'
        self._action_type = action_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .web_app_firewall_policy_rule import WebAppFirewallPolicyRule
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ProtectionRule(WebAppFirewallPolicyRule):
    """
    Rule that represents Request/Response Protection.
    Only actions of the following types are allowed to be referenced in this rule:
    * CHECK
    * RETURN_HTTP_RESPONSE
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ProtectionRule object with values from keyword arguments. The default value of the :py:attr:`~oci.waf.models.ProtectionRule.type` attribute
        of this class is ``PROTECTION`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this ProtectionRule.
            Allowed values for this property are: "ACCESS_CONTROL", "PROTECTION", "REQUEST_RATE_LIMITING"
        :type type: str

        :param name:
            The value to assign to the name property of this ProtectionRule.
        :type name: str

        :param condition_language:
            The value to assign to the condition_language property of this ProtectionRule.
            Allowed values for this property are: "JMESPATH"
        :type condition_language: str

        :param condition:
            The value to assign to the condition property of this ProtectionRule.
        :type condition: str

        :param action_name:
            The value to assign to the action_name property of this ProtectionRule.
        :type action_name: str

        :param protection_capabilities:
            The value to assign to the protection_capabilities property of this ProtectionRule.
        :type protection_capabilities: list[oci.waf.models.ProtectionCapability]

        :param protection_capability_settings:
            The value to assign to the protection_capability_settings property of this ProtectionRule.
        :type protection_capability_settings: oci.waf.models.ProtectionCapabilitySettings

        :param is_body_inspection_enabled:
            The value to assign to the is_body_inspection_enabled property of this ProtectionRule.
        :type is_body_inspection_enabled: bool

        """
        self.swagger_types = {
            'type': 'str',
            'name': 'str',
            'condition_language': 'str',
            'condition': 'str',
            'action_name': 'str',
            'protection_capabilities': 'list[ProtectionCapability]',
            'protection_capability_settings': 'ProtectionCapabilitySettings',
            'is_body_inspection_enabled': 'bool'
        }

        self.attribute_map = {
            'type': 'type',
            'name': 'name',
            'condition_language': 'conditionLanguage',
            'condition': 'condition',
            'action_name': 'actionName',
            'protection_capabilities': 'protectionCapabilities',
            'protection_capability_settings': 'protectionCapabilitySettings',
            'is_body_inspection_enabled': 'isBodyInspectionEnabled'
        }

        self._type = None
        self._name = None
        self._condition_language = None
        self._condition = None
        self._action_name = None
        self._protection_capabilities = None
        self._protection_capability_settings = None
        self._is_body_inspection_enabled = None
        self._type = 'PROTECTION'

    @property
    def protection_capabilities(self):
        """
        **[Required]** Gets the protection_capabilities of this ProtectionRule.
        An ordered list that references OCI-managed protection capabilities.
        Referenced protection capabilities are not necessarily executed in order of appearance. Their execution order
        is decided at runtime for improved performance.
        The array cannot contain entries with the same pair of capability key and version more than once.


        :return: The protection_capabilities of this ProtectionRule.
        :rtype: list[oci.waf.models.ProtectionCapability]
        """
        return self._protection_capabilities

    @protection_capabilities.setter
    def protection_capabilities(self, protection_capabilities):
        """
        Sets the protection_capabilities of this ProtectionRule.
        An ordered list that references OCI-managed protection capabilities.
        Referenced protection capabilities are not necessarily executed in order of appearance. Their execution order
        is decided at runtime for improved performance.
        The array cannot contain entries with the same pair of capability key and version more than once.


        :param protection_capabilities: The protection_capabilities of this ProtectionRule.
        :type: list[oci.waf.models.ProtectionCapability]
        """
        self._protection_capabilities = protection_capabilities

    @property
    def protection_capability_settings(self):
        """
        Gets the protection_capability_settings of this ProtectionRule.

        :return: The protection_capability_settings of this ProtectionRule.
        :rtype: oci.waf.models.ProtectionCapabilitySettings
        """
        return self._protection_capability_settings

    @protection_capability_settings.setter
    def protection_capability_settings(self, protection_capability_settings):
        """
        Sets the protection_capability_settings of this ProtectionRule.

        :param protection_capability_settings: The protection_capability_settings of this ProtectionRule.
        :type: oci.waf.models.ProtectionCapabilitySettings
        """
        self._protection_capability_settings = protection_capability_settings

    @property
    def is_body_inspection_enabled(self):
        """
        Gets the is_body_inspection_enabled of this ProtectionRule.
        Enables/disables body inspection for this protection rule.
        Only Protection Rules in RequestProtection can have this option enabled. Response body inspection will
        be available at a later date.


        :return: The is_body_inspection_enabled of this ProtectionRule.
        :rtype: bool
        """
        return self._is_body_inspection_enabled

    @is_body_inspection_enabled.setter
    def is_body_inspection_enabled(self, is_body_inspection_enabled):
        """
        Sets the is_body_inspection_enabled of this ProtectionRule.
        Enables/disables body inspection for this protection rule.
        Only Protection Rules in RequestProtection can have this option enabled. Response body inspection will
        be available at a later date.


        :param is_body_inspection_enabled: The is_body_inspection_enabled of this ProtectionRule.
        :type: bool
        """
        self._is_body_inspection_enabled = is_body_inspection_enabled

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
